@@ -6,27 +6,29 @@ use Test::More;
 
 use Cwd;
 my $cwd = cwd."/";
+$cwd .= 't/' if $cwd !~ /[\\\/]t[\\\/]?$/;
 
 eval'require GD';
 if ( $@) {
 	 plan skip_all => "Skip GD tests - GD not installed";
 } else {
-	plan tests => 4;
+	plan tests => 5;
 }
 use_ok ("Image::Thumbnail");
 
 my $t = new Image::Thumbnail(
 #	CHAT=>1,
 	module => "GD",
-	inputpath => $cwd."t/test.jpg",
+	inputpath => $cwd."test.jpg",
 	size=>55,
 	create=>1,
-	outputpath=> $cwd.'t/test_t.jpg',
+	outputpath=> $cwd.'test_t.jpg',
 );
 isa_ok($t, "Image::Thumbnail");
 
 ok( $t->{x}==55,"x");
 ok( $t->{y}==49, "y");
-unlink($cwd."t/test_t.jpg");
+unlink($cwd."test_t.jpg");
 
+isa_ok( $t->{object}, "GD::Image");
 
